@@ -32,13 +32,14 @@ class TutorMagics(Magics):
             else:
                 source = cell
         if not width or not height:
-            (width, height) = (800, 500)
-        code = urllib.parse.urlencode({"code": source})
+            (width, height) = ("100%", 500)
+        payload = urllib.parse.urlencode({"code": source, "py": "3"})
+        url = f"https://pythontutor.com/iframe-embed.html#{payload}&rawInputLstJSON=%5B%5D"
         display(
             IFrame(
-                f"http://pythontutor.com/iframe-embed.html#code={code}&py=3",
+                url,
                 width,
                 height,
                 extras=['frameborder="0"'],
             )
-        )
+        )
\ No newline at end of file
